@@ -1,7 +1,7 @@
-from base_api import kuda
+from .base_api import kuda
 import math
 import random
-from utils import generate_id, load_private_key, load_public_key
+from .utils import generate_id, load_private_key, load_public_key
 
 
 
